aboutsummaryrefslogtreecommitdiff
path: root/tests/integration/test-indicator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tests/integration/test-indicator.cpp')
-rw-r--r--tests/integration/test-indicator.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/tests/integration/test-indicator.cpp b/tests/integration/test-indicator.cpp
index dca0bb6..679ec2a 100644
--- a/tests/integration/test-indicator.cpp
+++ b/tests/integration/test-indicator.cpp
@@ -46,11 +46,11 @@ TEST_F(TestIndicator, PhoneChangeRoleVolume)
// start now the indicator, so it picks the new volumes
ASSERT_NO_THROW(startIndicator());
// Generate a random volume
QTime now = QTime::currentTime();
qsrand(now.msec());
- int randInt = qrand() % 100;
- double randomVolume = randInt / 100.0;
+ int randInt = qrand() % 33;
+ const double randomVolume = randInt / 100.0;
QSignalSpy &userAccountsSpy = *signal_spy_volume_changed_;
// set an initial volume to the alert role
@@ -557,11 +557,11 @@ TEST_F(TestIndicator, DesktopChangeRoleVolume)
// start now the indicator, so it picks the new volumes
ASSERT_NO_THROW(startIndicator());
// Generate a random volume
QTime now = QTime::currentTime();
qsrand(now.msec());
- int randInt = qrand() % 100;
- double randomVolume = randInt / 100.0;
+ int randInt = qrand() % 33;
+ const double randomVolume = randInt / 100.0;
// play a test sound, it should NOT change the role in the indicator
EXPECT_TRUE(startTestSound("multimedia"));
@@ -46,11 +46,11 @@ TEST_F(TestIndicator, PhoneChangeRoleVolume)
// start now the indicator, so it picks the new volumes
ASSERT_NO_THROW(startIndicator());
- // Generate a random volume
+ // Generate a random volume in the range [0...0.33]
QTime now = QTime::currentTime();
qsrand(now.msec());
@@ -557,11 +557,11 @@ TEST_F(TestIndicator, DesktopChangeRoleVolume)
// start now the indicator, so it picks the new volumes
ASSERT_NO_THROW(startIndicator());
- // Generate a random volume
+ // Generate a random volume in the range [0...0.33]
QTime now = QTime::currentTime();
qsrand(now.msec());